### Name: initPBShistory
### Title: Customized History Widget Functions
### Aliases: initPBShistory rmPBShistory addPBShistory forwPBShistory
###   backPBShistory jumpPBShistory clearPBShistory
### Keywords: utilities

### ** Examples

#Example of creating a custom history widget that saves values
#whenever the "plot" button is pressed, and updates the plot when
#back or next is pushed. A custom history is needed to achieve this 
#functionality since the normal history widget does not update plots
require(PBSmodelling)

#create a window Description to be used with createWin using astext=TRUE
#PS: watch out for escaping special characters which 
#    must be done twice (first for R, then PBSmodelling)

winDesc <- '
window title="Custom History"
vector names="a b k" labels="a b points" font="bold" values="1 1 1000" function=myPlot
grid 1 3
  button function=myHistoryBack text="<- Back"
  button function=myPlot text="Plot"
  button function=myHistoryForw text="Next ->"

grid 2 2
  label "Index"
  entry name="myHistoryIndex" width=5
  label "Size"
  entry name="myHistorySize" width=5
'
#convert text into vector with each line represented as a new element
winDesc <- strsplit(winDesc, "\n")[[1]]

#custome functions required to update plots after restoring history values
myHistoryBack <- function() {
  backPBShistory("myHistory")
  myPlot(saveVal=FALSE) #show the plot with saved values
}
myHistoryForw <- function() {
  forwPBShistory("myHistory")
  myPlot(saveVal=FALSE) #show the plot with saved values
}

myPlot <- function(saveVal=TRUE) {
        
  #save all data whenever plot is called (directly)
  if (saveVal)
    addPBShistory("myHistory")
        
  getWinVal(scope="L")
  tt <- 2*pi*(0:k)/k;
  x <- (1+sin(a*tt));  y <- cos(tt)*(1+sin(b*tt));
  plot(x, y)
}

initPBShistory("myHistory", "myHistoryIndex", "myHistorySize")
createWin(winDesc, astext=TRUE)



